# Working with Auto-Generated Code

This example demonstrates how ultraimport can make imports work correctly in auto-generated code without modifying the source files.

## The Problem

In this example, `file1.py` imports `file2` directly:

```python
# In file1.py
import file2  # This will fail in many contexts
```

This import would fail unless:
- The current working directory is the parent of the module
- The parent directory is in the Python path
- The import is changed to a relative import (which requires modifying the file)

## The Solution

With ultraimport, we can import `file1.py` with a proper package context:

```python
# Create a package context for the import
Stuff = ultraimport('__dir__/autogenerated/file1.py', 'Stuff', package='autogenerated')
```

The `package='autogenerated'` parameter creates a virtual package that gives the imported module the context it needs for its imports to work properly.

## Why This Matters

This approach is invaluable when working with:

- Auto-generated code (protobuf, ORM, API clients)
- Legacy systems
- Third-party libraries
- Code you cannot or should not modify

Instead of changing the generated files (which might be overwritten later), ultraimport lets you adapt to their structure dynamically.